@@ -1,6 +1,7 @@
 from .ettj import get_ettj, plot_ettj, listar_dias_uteis
+from .modelo_ettj import *
 from . import version
 
 __version__ = version.__version__
 
-__all__ = ["get_ettj", "plot_ettj", "listar_dias_uteis"]
\ No newline at end of file
+__all__ = ["get_ettj", "plot_ettj", "listar_dias_uteis", "get_ettj_anbima", "svensson"]
\ No newline at end of file
